@@ -7,6 +7,7 @@ from io import BytesIO
 from pyquaternion import Quaternion
 from typing import Any
 from scipy.spatial.transform import Rotation as R
+import open3d as o3d
 
 
 from .camera import LidarCamera
@@ -514,5 +515,22 @@ class LidarFrame:
         )
         return scale_file_upload(fileobj, project_name)
 
+    def downsample_frame(self, voxel_size_mm=250):
+        pcd = o3d.geometry.PointCloud()
+        normals = np.zeros((self.points.shape[0], 3), dtype=float)
+        normals[:, 0] = self.points[:, 3]
+
+        pcd.points = o3d.utility.Vector3dVector(self.points[:, :3])
+        pcd.normals = o3d.utility.Vector3dVector(normals)
+        pcd.colors = o3d.utility.Vector3dVector(self.colors)
+
+        pcd = pcd.voxel_down_sample(voxel_size_mm / 1000)
+
+        positions, intensities = np.asarray(pcd.points), np.asarray(pcd.normals)[:, 0]
+        points = np.hstack([positions, intensities.reshape(intensities.shape[0], 1)])
+
+        self.points = np.hstack([points, np.zeros((points.shape[0], 1), dtype=float)])
+        self.colors = np.asarray(pcd.colors)
+
     def __repr__(self):
         return "Frame({0}) {1}".format(self.id, self.transform)
