@@ -237,7 +237,7 @@ class LidarScene:
                 for frame in self.frames:
                     frame.s3_upload(bucket, path)
 
-        signed_url = get_signed_url(bucket, path)
+        signed_url = get_signed_url(bucket, f"{path}/scene.json")
 
         print(f"Scene uploaded: {signed_url}")
         return self.base_url
