@@ -7,7 +7,7 @@ class Transform:
     """Transform object represent a rigid transformation matrix (rotation and translation).
 
     Transform is a 4x4 matrix, although it could be instance using (16,1), (3,4), (3,3) or (3,1) matrixes.
-    (Have in mind that not all the method from Transform will work using scaled/small matrixes)
+    **Note**: not all the methods from Transform will work using scaled/small matrixes
 
     .. highlight:: python
     .. code-block:: python
@@ -20,6 +20,7 @@ class Transform:
       ]
 
     """
+
     def __init__(self, value=None):
         self.matrix = np.eye(4)
 
@@ -63,8 +64,8 @@ class Transform:
         return Transform(np.block([[R, np.mat(t).T], [np.zeros(3), 1]]))
 
     @staticmethod
-    def from_euler(angles, axes='sxyz', degrees=False):
-        """Create a transform based on euler angles
+    def from_euler(angles, axes="sxyz", degrees=False):
+        """Create a transform from euler angles
 
         :param angles: Values of the rotation per axis
         :type angles: list
@@ -72,7 +73,7 @@ class Transform:
         :type axes: str
         :param degrees: Use degrees or radians values (default ``False`` = radians)
         :type degrees: boolean
-        :returns: Transform created based on the angles
+        :returns: Transform created from euler angles
         :rtype: Transform
 
         """
@@ -82,13 +83,13 @@ class Transform:
 
     @staticmethod
     def from_transformed_points(A, B):
-        """Create a transform based on two points
+        """Create a transform from two points
 
         :param A: Point A (x,y,z)
         :type A: list
         :param B: Point B (x,y,z)
         :type B: list
-        :returns: Transform created based on the angles
+        :returns: Transform created from the angles
         :rtype: Transform
 
         """
@@ -175,7 +176,7 @@ class Transform:
         self.matrix[:3, 3] = np.array(translation).reshape(3)
 
     @property
-    def euler_angles(self, axes='sxyz'):
+    def euler_angles(self, axes="sxyz"):
         """Transform rotation in euler angles
 
         :getter: Return transform's rotaiton in euler angles
@@ -184,7 +185,7 @@ class Transform:
         return t3d.euler.mat2euler(self.matrix, axes=axes)
 
     @property
-    def euler_degrees(self, axes='sxyz'):
+    def euler_degrees(self, axes="sxyz"):
         """Transform rotation in euler degrees
 
         :getter: Return transform's rotaiton in euler degrees
@@ -214,7 +215,9 @@ class Transform:
 
         """
         try:
-            return Transform.from_Rt(self.rotation.T, np.dot(-self.rotation.T, self.translation))
+            return Transform.from_Rt(
+                self.rotation.T, np.dot(-self.rotation.T, self.translation)
+            )
         except ValueError:
             print("Can not inverse the Transform matrix")
 
@@ -241,11 +244,11 @@ class Transform:
         :rtype: Transform
 
         """
-        assert (0 <= factor <= 1.0)
+        assert 0 <= factor <= 1.0
         other = Transform(other)
         return self.from_Rt(
             Quaternion.slerp(self.quaternion, other.quaternion, factor),
-            self.position + factor * (other.position - self.position)
+            self.position + factor * (other.position - self.position),
         )
 
     def __array__(self):
@@ -266,7 +269,7 @@ class Transform:
         return np.allclose(self.matrix, other.matrix)
 
     def __repr__(self):
-        return 'R=%s t=%s' % (
+        return "R=%s t=%s" % (
             np.array_str(self.euler_degrees, precision=3, suppress_small=True),
-            np.array_str(self.position, precision=3, suppress_small=True)
+            np.array_str(self.position, precision=3, suppress_small=True),
         )
